==> apache-qpid-broker-j-8.0.6-bin.zip: dojo-1.16.3/dojo/cldr/nls/nb/ethiopic.js.uncompressed.js <==
define(
"dojo/cldr/nls/nb/ethiopic", //begin v1.x content
{
	"field-quarter-short-relative+0": "dette kv.",
	"field-quarter-short-relative+1": "neste kv.",
	"field-tue-relative+-1": "tirsdag sist uke",
	"field-year": "år",
	"field-wed-relative+0": "onsdag denne uken",
	"field-wed-relative+1": "onsdag neste uke",
	"field-minute": "minutt",
	"field-month-narrow-relative+-1": "forrige md.",
	"field-tue-narrow-relative+0": "denne ti.",
	"field-tue-narrow-relative+1": "neste ti.",
	"field-thu-short-relative+0": "denne tor.",
	"field-day-short-relative+-1": "i går",
	"field-thu-short-relative+1": "neste tor.",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i forgårs",
	"field-day-relative+1": "i morgen",
	"field-week-narrow-relative+0": "denne uken",
	"field-day-relative+2": "i overmorgen",
	"field-week-narrow-relative+1": "neste uke",
	"field-wed-narrow-relative+-1": "sist on.",
	"field-year-narrow": "år",
	"field-tue-relative+0": "tirsdag denne uken",
	"field-tue-relative+1": "tirsdag neste uke",
	"field-second-short": "sek",
	"field-week-relative+0": "denne uken",
	"field-month-relative+0": "denne måneden",
	"field-week-relative+1": "neste uke",
	"field-month-relative+1": "neste måned",
	"field-sun-narrow-relative+0": "denne sø.",
	"field-mon-short-relative+0": "denne man.",
	"field-sun-narrow-relative+1": "neste sø.",
	"field-mon-short-relative+1": "neste man.",
	"field-second-relative+0": "nå",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"eraNames": [
		"0. tidsalder",
		"1. tidsalder"
	],
	"field-month-short": "mnd.",
	"field-day": "dag",
	"field-year-relative+-1": "i fjor",
	"field-sat-short-relative+-1": "sist lør.",
	"field-hour-relative+0": "denne timen",
	"field-wed-relative+-1": "onsdag sist uke",
	"field-sat-narrow-relative+-1": "sist lø.",
	"field-second": "sekund",
	"field-quarter": "kvartal",
	"field-week-short": "uke",
	"field-tue-short-relative+0": "denne tir.",
	"field-tue-short-relative+1": "neste tir.",
	"field-month-short-relative+-1": "forrige md.",
	"field-mon-relative+-1": "mandag sist uke",
	"field-month": "måned",
	"field-day-narrow": "d.",
	"field-minute-short": "min",
	"field-dayperiod": "a.m./p.m.",
	"field-sat-short-relative+0": "denne lør.",
	"field-sat-short-relative+1": "neste lør.",
	"eraAbbr": [
		"0. t.a.",
		"1. t.a."
	],
	"field-second-narrow": "s",
	"field-mon-relative+0": "mandag denne uken",
	"field-mon-relative+1": "mandag neste uke",
	"field-year-short": "år",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-quarter-relative+-1": "forrige kvartal",
	"field-week-narrow-relative+-1": "forrige uke",
	"field-sat-relative+-1": "lørdag sist uke",
	"field-hour": "time",
	"months-format-wide": [
		"meskerem",
		"tekemt",
		"hedar",
		"tahsas",
		"ter",
		"yekatit",
		"megabit",
		"miazia",
		"genbot",
		"sene",
		"hamle",
		"nehasse",
		"pagumen"
	],
	"field-month-relative+-1": "forrige måned",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "denne lø.",
	"field-fri-relative+0": "fredag denne uken",
	"field-sat-narrow-relative+1": "neste lø.",
	"field-fri-relative+1": "fredag neste uke",
	"field-month-narrow-relative+0": "denne md.",
	"field-month-narrow-relative+1": "neste md.",
	"field-sun-short-relative+0": "denne søn.",
	"field-sun-short-relative+1": "neste søn.",
	"field-week-relative+-1": "forrige uke",
	"field-quarter-short-relative+-1": "forrige kv.",
	"months-format-abbr": [
		"meskerem",
		"tekemt",
		"hedar",
		"tahsas",
		"ter",
		"yekatit",
		"megabit",
		"miazia",
		"genbot",
		"sene",
		"hamle",
		"nehasse",
		"pagumen"
	],
	"field-quarter-relative+0": "dette kvartalet",
	"field-minute-relative+0": "dette minuttet",
	"field-quarter-relative+1": "neste kvartal",
	"field-wed-short-relative+-1": "sist ons.",
	"field-thu-short-relative+-1": "sist tor.",
	"field-mon-narrow-relative+-1": "sist ma.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "sist to.",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "sist ti.",
	"field-wed-short-relative+0": "denne ons.",
	"months-standAlone-wide": [
		"meskerem",
		"tekemt",
		"hedar",
		"tahsas",
		"ter",
		"yekatit",
		"megabit",
		"miazia",
		"genbot",
		"sene",
		"hamle",
		"nehasse",
		"pagumen"
	],
	"field-wed-short-relative+1": "neste ons.",
	"field-sun-relative+-1": "søndag sist uke",
	"field-weekday": "ukedag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "dette kv.",
	"field-sat-relative+0": "lørdag denne uken",
	"field-day-short-relative+1": "i morgen",
	"field-quarter-narrow-relative+1": "neste kv.",
	"field-sat-relative+1": "lørdag neste uke",
	"field-day-short-relative+2": "i overmorgen",
	"field-week-short-relative+0": "denne uken",
	"field-week-short-relative+1": "neste uke",
	"months-standAlone-abbr": [
		"meskerem",
		"tekemt",
		"hedar",
		"tahsas",
		"ter",
		"yekatit",
		"megabit",
		"miazia",
		"genbot",
		"sene",
		"hamle",
		"nehasse",
		"pagumen"
	],
	"field-month-short-relative+0": "denne md.",
	"field-month-short-relative+1": "neste md.",
	"field-thu-narrow-relative+0": "denne to.",
	"field-thu-narrow-relative+1": "neste to.",
	"field-sun-narrow-relative+-1": "sist sø.",
	"field-mon-short-relative+-1": "sist man.",
	"field-thu-relative+0": "torsdag denne uken",
	"field-thu-relative+1": "torsdag neste uke",
	"field-fri-short-relative+-1": "sist fre.",
	"field-thu-relative+-1": "torsdag sist uke",
	"field-week": "uke",
	"field-wed-narrow-relative+0": "denne on.",
	"field-wed-narrow-relative+1": "neste on.",
	"field-quarter-narrow-relative+-1": "forrige kv.",
	"field-fri-short-relative+0": "denne fre.",
	"field-fri-short-relative+1": "neste fre.",
	"field-week-short-relative+-1": "forrige uke",
	"field-hour-short": "t",
	"field-month-narrow": "md.",
	"field-hour-narrow": "t",
	"field-fri-narrow-relative+-1": "sist fr.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "neste år",
	"field-fri-relative+-1": "fredag sist uke",
	"eraNarrow": [
		"TA0",
		"TA1"
	],
	"field-tue-short-relative+-1": "sist tir.",
	"field-minute-narrow": "m",
	"field-mon-narrow-relative+0": "denne ma.",
	"field-mon-narrow-relative+1": "neste ma.",
	"field-zone": "tidssone",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "sist søn.",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"field-sun-relative+0": "søndag denne uken",
	"field-sun-relative+1": "søndag neste uke",
	"field-day-short": "dag",
	"field-week-narrow": "u.",
	"field-era": "tidsalder",
	"field-fri-narrow-relative+0": "denne fr.",
	"field-fri-narrow-relative+1": "neste fr."
}
//end v1.x content
);

==> apache-qpid-broker-j-10.0.1-bin.zip: dojo-1.17.3/dojo/cldr/nls/nb/ethiopic.js.uncompressed.js <==
define(
"dojo/cldr/nls/nb/ethiopic", //begin v1.x content
{
	"field-quarter-short-relative+0": "dette kv.",
	"field-quarter-short-relative+1": "neste kv.",
	"field-tue-relative+-1": "forrige tirsdag",
	"field-year": "år",
	"field-wed-relative+0": "onsdag",
	"field-wed-relative+1": "neste onsdag",
	"field-minute": "minutt",
	"field-month-narrow-relative+-1": "forrige md.",
	"field-tue-narrow-relative+0": "denne ti.",
	"field-tue-narrow-relative+1": "neste ti.",
	"field-day-short-relative+-1": "i går",
	"field-thu-short-relative+0": "denne tor.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i forgårs",
	"field-thu-short-relative+1": "neste tor.",
	"field-day-relative+1": "i morgen",
	"field-week-narrow-relative+0": "denne uken",
	"field-day-relative+2": "i overmorgen",
	"field-week-narrow-relative+1": "neste uke",
	"field-wed-narrow-relative+-1": "sist on.",
	"field-year-narrow": "år",
	"field-era-short": "tidsalder",
	"field-year-narrow-relative+0": "i år",
	"field-tue-relative+0": "tirsdag",
	"field-year-narrow-relative+1": "neste år",
	"field-tue-relative+1": "neste tirsdag",
	"field-weekdayOfMonth": "ukedag i måneden",
	"field-second-short": "sek",
	"dateFormatItem-yyyyMM": "MM.y G",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "uked. i md.",
	"field-week-relative+0": "denne uken",
	"field-month-relative+0": "denne måneden",
	"field-week-relative+1": "neste uke",
	"field-month-relative+1": "neste måned",
	"field-sun-narrow-relative+0": "denne sø.",
	"field-mon-short-relative+0": "denne man.",
	"field-sun-narrow-relative+1": "neste sø.",
	"field-mon-short-relative+1": "neste man.",
	"field-second-relative+0": "nå",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"eraNames": [
		"0. tidsalder",
		"1. tidsalder"
	],
	"field-weekOfMonth": "uke i måneden",
	"field-month-short": "mnd.",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-day": "dag",
	"field-dayOfYear-short": "dag i året",
	"field-year-relative+-1": "i fjor",
	"field-sat-short-relative+-1": "sist lør.",
	"field-hour-relative+0": "denne timen",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"field-second-short-relative+0": "nå",
	"field-wed-relative+-1": "forrige onsdag",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "sist lø.",
	"field-second": "sekund",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-quarter": "kvartal",
	"field-week-short": "uke",
	"field-day-narrow-relative+0": "i dag",
	"field-day-narrow-relative+1": "i morgen",
	"field-day-narrow-relative+2": "+2 d.",
	"field-tue-short-relative+0": "denne tir.",
	"field-tue-short-relative+1": "neste tir.",
	"field-month-short-relative+-1": "forrige md.",
	"field-mon-relative+-1": "forrige mandag",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "måned",
	"field-day-narrow": "d.",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "a.m./p.m.",
	"field-sat-short-relative+0": "denne lør.",
	"field-sat-short-relative+1": "neste lør.",
	"dateFormat-medium": "d. MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"0. t.a.",
		"1. t.a."
	],
	"dateFormatItem-yyyyM": "M.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "mandag",
	"field-mon-relative+1": "neste mandag",
	"field-day-narrow-relative+-1": "i går",
	"field-year-short": "år",
	"field-day-narrow-relative+-2": "-2 d.",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-quarter-relative+-1": "forrige kvartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-dayperiod-narrow": "am/pm",
	"field-week-narrow-relative+-1": "forrige uke",
	"field-dayOfYear": "dag i året",
	"field-sat-relative+-1": "forrige lørdag",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "time",
	"months-format-wide": [
		"meskerem",
		"tekemt",
		"hedar",
		"tahsas",
		"ter",
		"yekatit",
		"megabit",
		"miazia",
		"genbot",
		"sene",
		"hamle",
		"nehasse",
		"pagumen"
	],
	"dateFormat-full": "EEEE d. MMMM y G",
	"field-month-relative+-1": "forrige måned",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "denne lø.",
	"field-fri-relative+0": "fredag",
	"field-sat-narrow-relative+1": "neste lø.",
	"field-fri-relative+1": "neste fredag",
	"field-month-narrow-relative+0": "denne md.",
	"field-month-narrow-relative+1": "neste md.",
	"field-sun-short-relative+0": "denne søn.",
	"field-sun-short-relative+1": "neste søn.",
	"field-week-relative+-1": "forrige uke",
	"field-quarter-short-relative+-1": "forrige kv.",
	"months-format-abbr": [
		"meskerem",
		"tekemt",
		"hedar",
		"tahsas",
		"ter",
		"yekatit",
		"megabit",
		"miazia",
		"genbot",
		"sene",
		"hamle",
		"nehasse",
		"pagumen"
	],
	"field-quarter-relative+0": "dette kvartalet",
	"field-minute-relative+0": "dette minuttet",
	"field-quarter-relative+1": "neste kvartal",
	"field-wed-short-relative+-1": "sist ons.",
	"field-year-narrow-relative+-1": "i fjor",
	"field-thu-short-relative+-1": "sist tor.",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"field-mon-narrow-relative+-1": "sist ma.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "sist to.",
	"dateFormatItem-E": "ccc",
	"field-weekOfMonth-short": "uke i mnd.",
	"field-tue-narrow-relative+-1": "sist ti.",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "L.",
	"months-standAlone-wide": [
		"meskerem",
		"tekemt",
		"hedar",
		"tahsas",
		"ter",
		"yekatit",
		"megabit",
		"miazia",
		"genbot",
		"sene",
		"hamle",
		"nehasse",
		"pagumen"
	],
	"field-wed-short-relative+0": "denne ons.",
	"field-wed-short-relative+1": "neste ons.",
	"field-sun-relative+-1": "forrige søndag",
	"dateTimeFormat-full": "{1} {0}",
	"field-second-narrow-relative+0": "nå",
	"dateFormatItem-d": "d.",
	"field-weekday": "ukedag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "dette kv.",
	"field-day-short-relative+1": "i morgen",
	"field-sat-relative+0": "lørdag",
	"field-quarter-narrow-relative+1": "neste kv.",
	"field-day-short-relative+2": "i overmorgen",
	"field-sat-relative+1": "neste lørdag",
	"field-week-short-relative+0": "denne uken",
	"field-week-short-relative+1": "neste uke",
	"months-standAlone-abbr": [
		"meskerem",
		"tekemt",
		"hedar",
		"tahsas",
		"ter",
		"yekatit",
		"megabit",
		"miazia",
		"genbot",
		"sene",
		"hamle",
		"nehasse",
		"pagumen"
	],
	"field-dayOfYear-narrow": "d. i året",
	"field-month-short-relative+0": "denne md.",
	"field-month-short-relative+1": "neste md.",
	"field-weekdayOfMonth-short": "uked. i mnd.",
	"dateFormatItem-MEd": "E d.M",
	"field-zone-narrow": "tidssone",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "denne to.",
	"field-sun-narrow-relative+-1": "sist sø.",
	"field-mon-short-relative+-1": "sist man.",
	"field-thu-narrow-relative+1": "neste to.",
	"field-thu-relative+0": "torsdag",
	"field-thu-relative+1": "neste torsdag",
	"field-fri-short-relative+-1": "sist fre.",
	"field-thu-relative+-1": "forrige torsdag",
	"field-week": "uke",
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "denne on.",
	"field-wed-narrow-relative+1": "neste on.",
	"field-quarter-narrow-relative+-1": "forrige kv.",
	"field-year-short-relative+0": "i år",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "am/pm",
	"field-year-short-relative+1": "neste år",
	"field-fri-short-relative+0": "denne fre.",
	"field-fri-short-relative+1": "neste fre.",
	"field-week-short-relative+-1": "forrige uke",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "t",
	"field-zone-short": "tidssone",
	"field-month-narrow": "md.",
	"field-hour-narrow": "t",
	"field-fri-narrow-relative+-1": "sist fr.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "neste år",
	"field-era-narrow": "tidsalder",
	"field-fri-relative+-1": "forrige fredag",
	"eraNarrow": [
		"TA0",
		"TA1"
	],
	"field-tue-short-relative+-1": "sist tir.",
	"field-minute-narrow": "m",
	"field-mon-narrow-relative+0": "denne ma.",
	"field-mon-narrow-relative+1": "neste ma.",
	"field-year-short-relative+-1": "i fjor",
	"field-zone": "tidssone",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-weekOfMonth-narrow": "uke i md.",
	"field-weekday-narrow": "uked.",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "sist søn.",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"field-weekday-short": "ukedag",
	"field-sun-relative+0": "søndag",
	"dateFormatItem-MMdd": "d.M.",
	"field-sun-relative+1": "neste søndag",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dag",
	"field-week-narrow": "u.",
	"field-era": "tidsalder",
	"field-fri-narrow-relative+0": "denne fr.",
	"field-fri-narrow-relative+1": "neste fr."
}
//end v1.x content
);
